# Build

`coltrane` will render the `markdown` files into HTML and stored the generated file in an `output` folder. This is similar to other static site generators like `Jekyll` or `Hugo`.

## Record

The static site is built with the [`record` command](../cli.md#record).
